'\"
'\" Copyright (c) 1996, Michael Maul
'\" 
'\" Permission to use, copy, modify, distribute, and sell this software
'\" and its documentation for any purpose is hereby granted without fee,
'\" provided that the above copyright notice and this permission notice
'\" appear in all copies of the software and related documentation.
'\" 
'\" THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND,
'\" EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY
'\" WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
'\" 
'\" IN NO EVENT SHALL MICHAEL MAUL  BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
'\" INDIRECT OR CONSEQUENTIAL  OF ANY KIND, OR ANY DAMAGES WHATSOEVER
'\" RESULTING FROM LOSS  USE, DATA OR PROFITS, WHETHER OR NOT ADVISED
'\" OF THE POSSIBILITY  DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING
'\" OUT OF OR IN  WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
'\" 
'\" $Id: msqlicon.n,v 1.1 1996/08/23 23:37:01 kit Exp kit $
'\"
.TH "MsqlICON" ICON "" "ICON"
.ad b
.SH NAME
MsqlICON - mSQL (Mini SQL) server access commands for ICON
.SH "INTRODUCTION"
.P
MsqlICON is an Icon interface to the mSQL server. It consists of a number
of ICON wrapper functions, and a C library which provides access to mSQL.
Through the use of this package it is possible to access up to 16 mSQL 
servers simultaneously.
.P
The mSQL (Mini SQL) Database server was developed by David Huges at Bond 
University in Australia as part of a network programming project called 
Minerva. This server is capable of communication with applications via
UNIX sockets or ports, and provides a useful subset of the SQL language.
The mSQL package is available at ftp.bond.edu.au in /pub/Minerva/msql.
For more information on mSQL see the documentation provided in the mSQL 
distribution.
.sp
.SH "USAGE"
.br
Just link in the msqlicon library.
(ex. 
.B link msqlicon
)
.sp
.SH "MSQLICON FUNCTIONS"
.TP
.B msql_init ()
.br
Must be called before any other MsqlICON functions can be used.
.sp
.TP
.B msql_connect \fI(hostname)\fR
.br
Connects to an msql server on running on the host specified by \fIhostname\fR
. If no name is supplied 
.B msql_connect
defaults to the local host. A maximum of sixteen connections can be made
simultaneously. 
.sp
.B msql_connect
returns a handle, which is used in subsequent msqlicon function calls.
.sp
.B msql_connect 
fails if the host does not exist, or the server is not running. A detailed
error message can be obtained by calling 
.B msql_what_error
.
.sp
.TP
.B msql_seldb \fI(handle, dbname)\fR
.br
Selects a DB from the mSQL server referenced by \fIhandle\fR.
.sp
.B msql_seldb
fails if the handle is not valid, or no database \fIdbname\fR exists
A detailed error message can be obtained by calling 
.B msql_what_error
.sp
.TP
.B msql_select \fI(handle, sql-select-statement)\fR
.br
Sends \fIsql-statement\fR to the mSQL server. \fIsql-select-statement\fR must
be a valid sql select statement. (for other sql commands use 
.Bmsql_exec.
The \fIhandle\fR must be connected to a server and reference a valid database.
.sp
The results of the query are obtained through 
.B msql_fetch_row .
All results must be obtained before another select statement on \fIhandle\fR
is issued, or the results for \fIhandle\fR will be discarded.
.sp
.B msql_select
returns nothing, and succeeds if the select statement was successful. 
Otherwise this statement fails.  A detailed
error message can be obtained by calling 
.B msql_what_error

.sp
.sp
.TP
.B msql_exec \fI(handle, sql-statement)\fR
.br
Sends \fIsql-statement\fR to the database on the server referenced by 
\fIhandle\fR. \fIsql-statement\fR must be a valid sql statement that
is not a select statement (use 
.B msql_select
for select statements.
.sp
.B msql_exec
returns nothing and fails if the statement was successful, and fails otherwise.
.sp
.TP
.B msql_fetch_row \fI(handle)\fR
.br
Return the next row of the pending result, from a previous 
.B msql_select
command issued with \fIhandle\fR.
The row is returned as a Icon list, where each element corresponds to a
field specified in the previous select statement. The order of the list 
elements is the same was in the select statement that generated it. 
If there are no more rows the command fails.
.sp
.B msql_fetch_row 
fails if there is no pending result for \fIhandle\fR or
if the \fIhandle\fR is not a valid one.
.sp
.TP
.B msql_data_seek \fI(handle, row-index)\fR
.br
Moves the row cursor position relative to /fIrow-index/fR. Using 0 as
a row-index will move the cursor back to the first result. Using negative
numbers will move the cursor upwards through the rows with -1 referencing
the position above the last row. Positive row-index
will of course move the cursor downward. If the row-index exceeds the number
of rows returned, then the next call to 
.B msql_fetch_fow
.sp
.B msql_data_seek
fails if there is no pending result for \fIhandle\fR.
.sp
.TP 
.B msql_col_info \fI(handle, options)\fR
.br
Return information about the columns of a table.
\fIHandle\fR must be connected and reference results from a previous
.B msql_select
statement. One or more options contained in the list \fIoptions\fR control what
information to return.
.sp
Each option must be one of the following keywords.
.RS
.TP
.B name
.br
Return the name of a column.
.TP
.B type
.br
Return the type of a column; one of the strings \fBint\fR, \fBreal\fR,
\fBchar\fR.
.TP
.B length
.br
Return the length of a column in bytes.
.TP
.B table
.br
Return the name of the table in which this column occurs.
.TP
.B non_null
.br
Return the string ``1'' if the column is non-null; otherwise ``0''.
.TP
.B prim_key
.br
Return the string ``1'' if the column is part of the primary key;
otherwise ``0''.
.RE
.sp
This function returns results as an Icon list where each entry is
a list containing entries corresponding to the options specified in the
\fIoptions\fR list argument.
.sp
.TP 
.sp
.B msq_linfo \fI(handle, option)\fR
.br
Return various database information depending on the list \fIoption\fR.
The option must be one of the following keywords.
.RS
.TP
.B dbname
.br
Return the name of the database with which the handle is associated.
The handle must be in use.
.TP
.B host
.br
Return the name of the host to which the handle is connected.
The handle must be connected.
.RE
.TP 
.sp
.B msql_result \fI(handle, option)\fR
.br
Return information about the pending result as an Icon string.
\fIOption\fR must be one of the following keywords.
.RS
.TP
.B cols
.br
Return the number of columns in the pending result.
There must be a pending result.
.TP
.B current
.br
Return the current position in the pending result; a non-negative integer.
This value can be used as \fIrow-index\fR in the msqlseek command.
An error is raised if there is no pending result.
.TP
.B rows
.br
Return the number of rows that can be read sequentially from the
current position in the pending result.
There must be a pending result.
.sp
.RE
.TP
.B msql_list_dbs \fIhandle\fR
Lists the available databases on the mSQL server referenced by \fIhandle\fR.
Returns a list of available databases as a Icon list.
.sp
.B msql_list_dbs 
fails if the handle is invalid.
.sp
.TP
.B msql_list_tables \fIhandle\fR
Returns a list of tables contained in the database referenced by 
\fIhandle\fR as a Icon list.
.sp
.B msql_list_tables 
fails if the handle is invalid.
.sp
.TP
.B msql_what_error ()
Returns the error message from the mSQL server concerning the latest failed
request.
.TP
.sp
.B msqlclose \fI(handle)\fR
.br
Closes the server connection associated with \fIhandle\fR, causing it
to go back to the unconnected state.
Closes all connections if \fIhandle\fR is omitted.
Returns an empty string.
Msqlclose fails if a handle is specified which is not
connected.
.sp
.SH ENVIRONMENT VARIABLES
.P
None.
.sp
.SH BUGS & POSSIBLE MISFEATURES
.P
Probably.
.sp
.SH AUTHOR
Michael Maul (maul@sol.cms.uncwil.edu), Undergrad Student,  
University of NC @ Wilmington, Wilmington, NC.
MsqlICON is based on Msqltcl by  Hakan  Soderstrom  (hs@soderstrom.se).
.sp
$Revision: 1.1 $
